@@ -98,6 +98,9 @@ public class PredefMacros {
         NewCommandMacro.addNewCommand("with", "\\mathbin{\\&}", 0);
         NewCommandMacro.addNewCommand("parr", "\\mathbin{\\rotatebox[origin=c]{180}{\\&}}", 0);
         NewCommandMacro.addNewCommand("copyright", "\\textcircled{\\raisebox{0.2ex}{c}}", 0);
+        NewCommandMacro.addNewCommand("L", "\\mathrm{\\polishlcross L}", 0);
+        NewCommandMacro.addNewCommand("l", "\\mathrm{\\polishlcross l}", 0);
+        NewCommandMacro.addNewCommand("Join", "\\mathop{\\rlap{\\ltimes}\\rtimes}", 0);
     }
 
     public static final Atom Braket_macro(final TeXParser tp, final String[] args) throws ParseException {
@@ -714,11 +717,11 @@ public class PredefMacros {
             ArrayOfAtoms array = new ArrayOfAtoms();
             array.add(tp.formula.root);
             array.addRow();
-            TeXParser parser = new TeXParser(tp.getIsPartial(), tp.getStringFromCurrentPos(), array, false);
+            TeXParser parser = new TeXParser(tp.getIsPartial(), tp.getStringFromCurrentPos(), array, false, tp.isIgnoreWhiteSpace());
             parser.parse();
             array.checkDimensions();
             tp.finish();
-            tp.formula.root = new MatrixAtom(tp.getIsPartial(), array, MatrixAtom.ARRAY, TeXConstants.ALIGN_LEFT);
+            tp.formula.root = array.getAsVRow();//new MatrixAtom(tp.getIsPartial(), array, MatrixAtom.ARRAY, TeXConstants.ALIGN_LEFT, false);
         }
 
         return null;
@@ -781,7 +784,7 @@ public class PredefMacros {
         TeXParser parser = new TeXParser(tp.getIsPartial(), args[2], array, false);
         parser.parse();
         array.checkDimensions();
-        return new MatrixAtom(tp.getIsPartial(), array, args[1]);
+        return new MatrixAtom(tp.getIsPartial(), array, args[1], true);
     }
 
     public static final Atom alignATATenv_macro(final TeXParser tp, final String[] args) throws ParseException {
