@@ -81,7 +81,7 @@ import java.lang.Character.UnicodeBlock;
  */
 public class TeXFormula {
 
-    public static final String VERSION = "1.0.0";
+    public static final String VERSION = "1.0.2";
 
     public static final int SERIF = 0;
     public static final int SANSSERIF = 1;
@@ -166,6 +166,16 @@ public class TeXFormula {
         tfsp.parseSymbolToFormulaMappings(symbolFormulaMappings, symbolTextMappings);
     }
 
+    public static FontInfos getExternalFont(Character.UnicodeBlock block) {
+        FontInfos infos = externalFontMap.get(block);
+        if (infos == null) {
+            infos = new FontInfos("SansSerif", "Serif");
+            externalFontMap.put(block, infos);
+        }
+
+        return infos;
+    }
+
     public static void registerExternalFont(Character.UnicodeBlock block, String sansserif, String serif) {
         if (sansserif == null && serif == null) {
             externalFontMap.remove(block);
@@ -420,6 +430,13 @@ public class TeXFormula {
                     root = new RowAtom(root);
                 }
                 ((RowAtom) root).add(el);
+                if (el instanceof TypedAtom) {
+                    TypedAtom ta = (TypedAtom) el;
+                    int rtype = ta.getRightType();
+                    if (rtype == TeXConstants.TYPE_BINARY_OPERATOR || rtype == TeXConstants.TYPE_RELATION) {
+                        ((RowAtom) root).add(new BreakMarkAtom());
+                    }
+                }
             }
         }
         return this;
@@ -591,6 +608,205 @@ public class TeXFormula {
         return dtf;
     }
 
+    /**
+     * Apply the Builder pattern instead of using the createTeXIcon(...) factories
+     * @author Felix Natter
+     *
+     */
+    public class TeXIconBuilder {
+        private Integer style;
+        private Float size;
+        private Integer type;
+        private Color fgcolor;
+        private boolean trueValues = false;
+        private Integer widthUnit;
+        private Float textWidth;
+        private Integer align;
+        private boolean isMaxWidth = false;
+        private Integer interLineUnit;
+        private Float interLineSpacing;
+
+        /**
+         * Specify the style for rendering the given TeXFormula
+         * @param style the style
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setStyle(final int style)
+            {
+                this.style = style;
+                return this;
+            }
+
+        /**
+         * Specify the font size for rendering the given TeXFormula
+         * @param size the size
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setSize(final float size)
+            {
+                this.size = size;
+                return this;
+            }
+
+        /**
+         * Specify the font type for rendering the given TeXFormula
+         * @param type the font type
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setType(final int type)
+            {
+                this.type = type;
+                return this;
+            }
+
+        /**
+         * Specify the background color for rendering the given TeXFormula
+         * @param fgcolor the foreground color
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setFGColor(final Color fgcolor)
+            {
+                this.fgcolor = fgcolor;
+                return this;
+            }
+
+        /**
+         * Specify the "true values" parameter for rendering the given TeXFormula
+         * @param trueValues the "true values" value
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setTrueValues(final boolean trueValues)
+            {
+                this.trueValues = trueValues;
+                return this;
+            }
+
+        /**
+         * Specify the width of the formula (may be exact or maximum width, see {@link #setIsMaxWidth(boolean)})
+         * @param widthUnit the width unit
+         * @param textWidth the width
+         * @param align the alignment
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setWidth(final int widthUnit, final float textWidth, final int align)
+            {
+                this.widthUnit = widthUnit;
+                this.textWidth = textWidth;
+                this.align = align;
+                trueValues = true; // TODO: is this necessary?
+                return this;
+            }
+
+        /**
+         * Specifies whether the width is the exact or the maximum width
+         * @param isMaxWidth whether the width is a maximum width
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setIsMaxWidth(final boolean isMaxWidth)
+            {
+                if (widthUnit == null)
+                {
+                    throw new IllegalStateException("Cannot set 'isMaxWidth' without having specified a width!");
+                }
+                if (isMaxWidth)
+                {
+                    // NOTE: Currently isMaxWidth==true does not work with ALIGN_CENTER or ALIGN_RIGHT (see HorizontalBox ctor)
+                    // The case (1) we don't support by setting align := ALIGN_LEFT here is this:
+                    //  \text{hello world\\hello} with align=ALIGN_CENTER (but forced to ALIGN_LEFT) and isMaxWidth==true results in:
+                    // [hello world]
+                    // [hello      ]
+                    // and NOT:
+                    // [hello world]
+                    // [   hello   ]
+                    // However, this case (2) is currently not supported anyway (ALIGN_CENTER with isMaxWidth==false):
+                    // [  hello world  ]
+                    // [  hello        ]
+                    // and NOT:
+                    // [  hello world  ]
+                    // [     hello     ]
+                    // => until (2) is solved, we stick with the hack to set align := ALIGN_LEFT!
+                    this.align = TeXConstants.ALIGN_LEFT;
+                }
+                this.isMaxWidth = isMaxWidth;
+                return this;
+            }
+
+        /**
+         * Specify the inter line spacing unit and value. NOTE: this is required for automatic linebreaks to work!
+         * @param interLineUnit the unit
+         * @param interLineSpacing the value
+         * @return the builder, used for chaining
+         */
+        public TeXIconBuilder setInterLineSpacing(final int interLineUnit, final float interLineSpacing)
+            {
+                if (widthUnit == null)
+                {
+                    throw new IllegalStateException("Cannot set inter line spacing without having specified a width!");
+                }
+                this.interLineUnit = interLineUnit;
+                this.interLineSpacing = interLineSpacing;
+                return this;
+            }
+
+        /**
+         * Create a TeXIcon from the information gathered by the (chained) setXXX() methods.
+         * (see Builder pattern)
+         * @return the TeXIcon
+         */
+        public TeXIcon build()
+            {
+                if (style == null)
+                {
+                    throw new IllegalStateException("A style is required. Use setStyle()");
+                }
+                if (size == null)
+                {
+                    throw new IllegalStateException("A size is required. Use setStyle()");
+                }
+                DefaultTeXFont font = (type == null) ? new DefaultTeXFont(size) : createFont(size, type);
+                TeXEnvironment te;
+                if (widthUnit != null)
+                {
+                    te = new TeXEnvironment(style, font, widthUnit, textWidth);
+                }
+                else
+                {
+                    te = new TeXEnvironment(style, font);
+                }
+
+		if (interLineUnit != null) {
+		    te.setInterline(interLineUnit, interLineSpacing);
+		}
+
+                Box box = createBox(te);
+                TeXIcon ti;
+                if (widthUnit != null)
+                {
+                    HorizontalBox hb;
+                    if (interLineUnit != null)
+                    {
+                        float il = interLineSpacing * SpaceAtom.getFactor(interLineUnit, te);
+                        Box b = BreakFormula.split(box, te.getTextwidth(), il);
+                        hb = new HorizontalBox(b, isMaxWidth ? b.getWidth() : te.getTextwidth(), align);
+                    }
+                    else
+                    {
+                        hb = new HorizontalBox(box, isMaxWidth ? box.getWidth() : te.getTextwidth(), align);
+                    }
+                    ti = new TeXIcon(hb, size, trueValues);
+                }
+                else
+                {
+                    ti = new TeXIcon(box, size, trueValues);
+                }
+                if (fgcolor != null) {
+                    ti.setForeground(fgcolor);
+                }
+                ti.isColored = te.isColored;
+                return ti;
+            }
+    }
+
     /**
      * Creates a TeXIcon from this TeXFormula using the default TeXFont in the given
      * point size and starting from the given TeX style. If the given integer value
@@ -602,38 +818,19 @@ public class TeXFormula {
      * @return the created TeXIcon
      */
     public TeXIcon createTeXIcon(int style, float size) {
-        TeXEnvironment te = new TeXEnvironment(style, new DefaultTeXFont(size));
-        Box box = createBox(te);
-        TeXIcon ti = new TeXIcon(box, size);
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).build();
     }
 
     public TeXIcon createTeXIcon(int style, float size, int type) {
-        TeXEnvironment te = new TeXEnvironment(style, createFont(size, type));
-        Box box = createBox(te);
-        TeXIcon ti = new TeXIcon(box, size);
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).setType(type).build();
     }
 
     public TeXIcon createTeXIcon(int style, float size, int type, Color fgcolor) {
-        TeXEnvironment te = new TeXEnvironment(style, createFont(size, type));
-        Box box = createBox(te);
-        TeXIcon ti = new TeXIcon(box, size);
-        if (fgcolor != null) {
-            ti.setForeground(fgcolor);
-        }
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).setType(type).setFGColor(fgcolor).build();
     }
 
     public TeXIcon createTeXIcon(int style, float size, boolean trueValues) {
-        TeXEnvironment te = new TeXEnvironment(style, new DefaultTeXFont(size));
-        Box box = createBox(te);
-        TeXIcon ti = new TeXIcon(box, size, trueValues);
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).setTrueValues(trueValues).build();
     }
 
     public TeXIcon createTeXIcon(int style, float size, int widthUnit, float textwidth, int align) {
@@ -641,13 +838,7 @@ public class TeXFormula {
     }
 
     public TeXIcon createTeXIcon(int style, float size, int type, int widthUnit, float textwidth, int align) {
-        TeXEnvironment te = new TeXEnvironment(style, createFont(size, type), widthUnit, textwidth);
-        Box box = createBox(te);
-        HorizontalBox hb = new HorizontalBox(box, te.getTextwidth(), align);
-
-        TeXIcon ti = new TeXIcon(hb, size, true);
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).setType(type).setWidth(widthUnit, textwidth, align).build();
     }
 
     public TeXIcon createTeXIcon(int style, float size, int widthUnit, float textwidth, int align, int interlineUnit, float interline) {
@@ -655,14 +846,7 @@ public class TeXFormula {
     }
 
     public TeXIcon createTeXIcon(int style, float size, int type, int widthUnit, float textwidth, int align, int interlineUnit, float interline) {
-        TeXEnvironment te = new TeXEnvironment(style, createFont(size, type), widthUnit, textwidth);
-        Box box = createBox(te);
-        float il = interline * SpaceAtom.getFactor(interlineUnit, te);
-        HorizontalBox hb = new HorizontalBox(BreakFormula.split(box, te.getTextwidth(), il), te.getTextwidth(), align);
-
-        TeXIcon ti = new TeXIcon(hb, size, true);
-        ti.isColored = te.isColored;
-        return ti;
+        return new TeXIconBuilder().setStyle(style).setSize(size).setType(type).setWidth(widthUnit, textwidth, align).setInterLineSpacing(interlineUnit, interline).build();
     }
 
     public void createImage(String format, int style, float size, String out, Color bg, Color fg, boolean transparency) {
