@@ -198,6 +198,20 @@ public class TeXParser {
         arrayMode = true;
     }
 
+    /**
+     * Create a new TeXParser in the context of an array. When the parser meets a & a new atom is added in the current line and when a \\ is met, a new line is created.
+     *
+     * @param isPartial if true certains exceptions are not thrown
+     * @param parseString the string to be parsed
+     * @param aoa an ArrayOfAtoms where to put the elements
+     * @param firstpass a boolean to indicate if the parser must replace the user-defined macros by their content
+     * @throws ParseException if the string could not be parsed correctly
+     */
+    public TeXParser(boolean isPartial, String parseString, ArrayOfAtoms aoa, boolean firstpass, boolean space) {
+        this(isPartial, parseString, (TeXFormula) aoa, firstpass, space);
+        arrayMode = true;
+    }
+
     /**
      * Create a new TeXParser in the context of an array. When the parser meets a & a new atom is added in the current line and when a \\ is met, a new line is created.
      *
@@ -649,6 +663,7 @@ public class TeXParser {
                     pos++;
                     if (!ignoreWhiteSpace) {// We are in a mbox
                         formula.add(new SpaceAtom());
+                        formula.add(new BreakMarkAtom());
                         while (pos < len) {
                             ch = parseString.charAt(pos);
                             if (ch != ' ' || ch != '\t' || ch != '\r')
@@ -1092,7 +1107,7 @@ public class TeXParser {
 
             String symbolName = TeXFormula.symbolMappings[c];
             if (symbolName == null && (TeXFormula.symbolFormulaMappings == null || TeXFormula.symbolFormulaMappings[c] == null)) {
-                TeXFormula.FontInfos fontInfos = TeXFormula.externalFontMap.get(block);
+                TeXFormula.FontInfos fontInfos = TeXFormula.getExternalFont(block);
                 if (fontInfos != null) {
                     if (oneChar) {
                         return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
@@ -1177,7 +1192,12 @@ public class TeXParser {
             pos++;
         }
 
-        return parseString.substring(spos, pos);
+        String com = parseString.substring(spos, pos);
+        if ("cr".equals(com) && pos < len && parseString.charAt(pos) == ' ') {
+            pos++;
+        }
+
+        return com;
     }
 
     private Atom processEscape() throws ParseException {
